@@ -1077,7 +1077,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         self.clear_changes()
 
     def on_driver_restart_clicked(self, button_restart):
-        subprocess.call(['/usr/lib/indicator-session/gtk-logout-helper', '--shutdown'])
+        subprocess.call(['/usr/lib/indicator-session/gtk-logout-helper', '--restart'])
 
     def clear_changes(self):
         self.orig_selection = {}
