@@ -136,15 +136,19 @@ class AddPPASigningKeyThread(Thread):
         self.ppa_path = ppa_path
         self.keyserver = (keyserver if keyserver is not None
                           else DEFAULT_KEYSERVER)
-        
+
     def run(self):
         self.add_ppa_signing_key(self.ppa_path)
-        
+
     def _recv_key(self, keyring, secret_keyring, signing_key_fingerprint, keyring_dir):
-        # double check that the signing key is a v4 fingerprint (160bit)
-        if not verify_keyid_is_v4(signing_key_fingerprint):
-            print("Error: signing key fingerprint '%s' too short" % 
-                  signing_key_fingerprint)
+        try:
+            # double check that the signing key is a v4 fingerprint (160bit)
+            if not verify_keyid_is_v4(signing_key_fingerprint):
+                print("Error: signing key fingerprint '%s' too short" % 
+                    signing_key_fingerprint)
+                return False
+        except TypeError:
+            print("Error: signing key fingerprint does not exist")
             return False
         # then get it
         res = subprocess.call(self.GPG_DEFAULT_OPTIONS + [
